# -*- coding: utf-8 -*-

from django.contrib import admin
from django.utils.html import format_html
from django.conf import settings

from .models import Category, Reference


class CategoryAdmin(admin.ModelAdmin):
    list_display = [
        'name',
        'order',
        'enabled',
    ]


class ReferenceAdmin(admin.ModelAdmin):
    list_display = [
        'name',
        'link',
        'image_url',
        'order',
        'enabled',
    ]
    list_filter = [
        'categories',
    ]

    def image_url(self, reference):
        if not reference.image:
            return ''
        return format_html('<img style="height: 1em" src="{}" alt="{repr}" />{repr}',
                           reference.image.url,
                           repr=str(reference))


if 'adminsortable2' in settings.INSTALLED_APPS:
    from adminsortable2.admin import SortableAdminMixin
    CategoryAdmin = type(CategoryAdmin)('CategoryAdmin', (SortableAdminMixin, CategoryAdmin), {})
    ReferenceAdmin = type(ReferenceAdmin)('ReferenceAdmin', (SortableAdminMixin, ReferenceAdmin), {})


admin.site.register(Category, CategoryAdmin)
admin.site.register(Reference, ReferenceAdmin)
