# -*- coding: utf-8 -*-

from django.test import TestCase

from ..models import ReferencePlugin as ReferencePluginModel


class ReferencePluginTest(TestCase):
    fixtures = [
        'reference_cmsplugin/tests/test_plugin.yaml',
    ]

    def test_plugin_context_categories(self):
        model_instance = ReferencePluginModel.objects.get(pk=2)
        plugin_instance = model_instance.get_plugin_class_instance()
        context = plugin_instance.render({}, model_instance, None)
        assert context['instance'] == model_instance
        assert list(context['references'].values_list('id', flat=True)) == [1, 2]

    def test_plugin_order(self):
        model_instance = ReferencePluginModel.objects.get(pk=2)
        plugin_instance = model_instance.get_plugin_class_instance()
        context = plugin_instance.render({}, model_instance, None)

        assert context['categories'].query.order_by == ['order']
        assert context['references'].query.order_by == ['order']

    def test_plugin_empty_categories(self):
        model_instance = ReferencePluginModel.objects.get(pk=1)
        plugin_instance = model_instance.get_plugin_class_instance()
        context = plugin_instance.render({}, model_instance, None)
        assert context['instance'] == model_instance
        assert list(context['references'].values_list('id', flat=True)) == [1, 2, 3]
